---
title: "ADHD & Notetaking: an autistic perspective"
date: 2021-08-07
...
If you are living with ADHD, diagnosed or not, the following things
might sound familiar: *"I forgot to write that down"*, *"I forgot to do
that"*, *"I don't remember that"*.

If you ask neurotypical people what they do to resolve that, they will
probably give you answers ranging from "Oh I just have it all in my
head" to "Just use a todo list / GTD system / bullet journal", both
equally unhelpful to most neurodiverse folks I know.

Reading [this article](https://xeiaso.net/blog/gtd-on-paper-2021-06-13){target="_blank"} by Xe inspired me to tackle
this
problem for myself. (I highly encourage you to read the linked post
along with the rest of their blog)

Now, back to the topic at hand. As mentioned, there are many common
strategies for managing tasks and notes, many of which simply do not
work for me, but let's go through the why and try to find something that
works from there.

### Journals, paper and other physical ways of notetaking

The most immediate problem with this one is something many ADHD folks
will know very well - keeping track of the physical thing. Many times
have I lost track of notebooks, journals, diaries or anything related,
often times not finding them again to this day. For something I have to
rely on (physical extension of my brain, my memories, my thoughts),
that's bad. It's hard to forget your head, after all - even though a
certain figure of speech might suggest otherwise.

Another issue, that links more into the *autistic perspective* part of
the title, is the thing that many people like about paper - its
append-only nature. I have very specific ideas about how I want things
structured - and those ideas and needs vary with time and with the
contents of the page. You just can't (easily and realistically) re-write
the entire page every time those change, which makes paper inconvenient
at best and irritating at worst.

But there are also some wonderful things about paper, some even come as
a direct consequence of the problems I just described. You can just
start writing, there are no creative restrictions on what you can and
can't write, draw or otherwise do with the page, there is no fixed set
of design choices, style guidelines and whatnot. The append-only nature
also forces you to stop worrying about mistakes, and ideally should let
you be in full control of writing out thoughts.

To summarize: Paper is problematic because of the physical and
append-only nature, but can also great because of the freedom and
implicit restrictions it brings onto the table. What I then set out to
do is translating those concepts into the digital world, as closely
adhering to those concepts (and other things my brain likes that I
didn't cover in this post) as possible.

### Markdown and the digital world

Once you dabble with digital notetaking for more than a few minutes,
there's no way not to stumble upon Markdown. And there's good reason for
that, being an easy to understand, simple and human-readable (in
contrast to programmer-readable) markup language.

Those things also bring caveats with them, however. Simplicity
inherently means limitation, and that's also true here. There isn't that
much most Markdown renderers can do. Even worse, there is fragmentation
in the Markdown space, with plain Markdown, GitHub-flavored Markdown
(GFM) and MultiMarkdown as examples, not to speak of the variety of ways
different renderers for the same specification actually interpret
things.

Where does that leave us, then? I think Markdown is great, just not the
full story we need here. It's a great starting point, and that's why my
personal solution builds upon Markdown. So what is it that I currently
(and thus far successfully, i.e. there when I need it, how I need it, as
I want it) use?

It's a combination of [Obsidian](https://obsidian.md){target="_blank"} (a fancy
Markdown editor, self-proclaimed "second brain"), some plugins, a custom
theme, and most importantly, *not using the Markdown __renderer__*. You
might wonder how that works, isn't markdown supposed to be rendered? To
which I say - yes, but we can do better. The one thing you are losing
with that click of a button is control. Suddenly you have the version of
what you wrote in front of you that the renderer decided on, not how you
wanted it to look and feel. Which defeats the entire purpose of this
project, to get something that offers creative freedom close to physical
paper, without being convoluted to use.

### Putting it all together

So how does my setup look like exactly? Like
[this](/files/blog/adhd-and-notes.png){target="_blank"}. Let me
explain what you are looking at here. On the left there is a tree view
of the directory structure that is currently open in Obsidian.

From top to bottom: *Events* are things like conferences and similar,
*Journal* is where the daily notes go, *Knowledge* is a categorized map
of information and trivia that might be useful again in the future,
*Meta* is stuff relevant for debugging Obsidian itself, *Notes* are
uncategorized but titled notes, *People* is for keeping track of people
I know (for the non-ADHD people reading this, yes, this is necessary, I
regularly forget basic things about people very close to me), *Places*
is the same thing but for Places like restaurants and stuff (important
to keep track of what I eat and where to get it and stuff), *Projects*
is pretty self-explanatory, *Vault* is the "system folder" where all the
templates and attachments go, and *Zettelkasten* is for untitled notes.
I have a shortcut configured that will create one of those untitled
notes so I can just type out a thought and figure out what it's about
later.

The file that's open is the daily journal template. This is used to
automatically generate the daily journal entry when I click on a date in
the calendar applet you can see on the top right. I then type out basic
info about the day (where I was when I woke up, when I woke up) and move
over incomplete TODOs from yesterday's daily note. You will also notice
the text editor is, well, in edit mode, with a nice monospace font. This
allows me to customize the spacing of individual elements in the
documents however I want (just like paper), which would all get lost
when rendering to HTML.

### Summary and conclusion

This setup allows me to write freely, structure everything the same way
my brain is structured, keep track of what I've been doing, keep track
of things that still need to be done, and much more. Have I forgotten
about it? Yes - two times over the past month. In comparison to previous
methods, this is great! It's also fairly easy to reconstruct the past
day or two, so I think I'm doing okay.

I won't pretend that this system will work for everyone, but I do hope
that you will find some useful information in this writeup. If you have
any questions (or want me to help you with Markdown, Obsidian or any
other part of this setup), feel free to contact me. (Links for that are
on the [main site](/#contact))

I hope this post was interesting for you, being the first time I've ever
written one like it. If you have any comments on the blog or my writing
style or just this post in general, please contact me as well. In any
case, thanks for reading and have a wonderful day!
